pub struct StripGenerator {
pub(crate) level: Level,
line_buf: Vec<Line>,
flatten_ctx: FlattenCtx,
stroke_ctx: StrokeCtx,
temp_storage: StripStorage,
tiles: Tiles,
width: u16,
height: u16,
}Expand description
An object for easily generating strips for a filled/stroked path.
Fields
level: Levelline_buf: Vec<Line>flatten_ctx: FlattenCtxstroke_ctx: StrokeCtxtemp_storage: StripStoragetiles: Tileswidth: u16height: u16Implementations
Sourceimpl StripGenerator
impl StripGenerator
Sourcepub fn generate_filled_path(
&mut self,
path: impl IntoIterator<Item = PathEl>,
fill_rule: Fill,
transform: Affine,
aliasing_threshold: Option<u8>,
strip_storage: &mut StripStorage,
clip_path: Option<PathDataRef<'_>>,
)
pub fn generate_filled_path( &mut self, path: impl IntoIterator<Item = PathEl>, fill_rule: Fill, transform: Affine, aliasing_threshold: Option<u8>, strip_storage: &mut StripStorage, clip_path: Option<PathDataRef<'_>>, )
Generate the strips for a filled path.
Sourcepub fn generate_stroked_path(
&mut self,
path: impl IntoIterator<Item = PathEl>,
stroke: &Stroke,
transform: Affine,
aliasing_threshold: Option<u8>,
strip_storage: &mut StripStorage,
clip_path: Option<PathDataRef<'_>>,
)
pub fn generate_stroked_path( &mut self, path: impl IntoIterator<Item = PathEl>, stroke: &Stroke, transform: Affine, aliasing_threshold: Option<u8>, strip_storage: &mut StripStorage, clip_path: Option<PathDataRef<'_>>, )
Generate the strips for a stroked path.
fn generate_with_clip( &mut self, aliasing_threshold: Option<u8>, strip_storage: &mut StripStorage, fill_rule: Fill, clip_path: Option<PathDataRef<'_>>, )
Sourcepub fn generate_filled_rect_fast(
&mut self,
rect: &Rect,
strip_storage: &mut StripStorage,
clip_path: Option<PathDataRef<'_>>,
)
pub fn generate_filled_rect_fast( &mut self, rect: &Rect, strip_storage: &mut StripStorage, clip_path: Option<PathDataRef<'_>>, )
Generate strips directly for a pixel-aligned rectangle.
This bypasses the full path processing pipeline (flatten -> tiles -> strips) by directly creating strip coverage data for the rectangle.