StripStorage

Struct StripStorage 

pub struct StripStorage {
    pub strips: Vec<Strip>,
    pub alphas: Vec<u8>,
    generation_mode: GenerationMode,
}
A storage for storing strip-related data.

Fields

strips: Vec<Strip>

The strips in the storage.

alphas: Vec<u8>

The alphas in the storage.

generation_mode: GenerationMode

Implementations

Source

impl StripStorage

pub fn new(generation_mode: GenerationMode) -> Self

Create a new strip storage with the given generation mode.

pub fn clear(&mut self)

Reset the storage.

pub fn generation_mode(&self) -> GenerationMode

Get the current generation mode.

pub fn set_generation_mode(&mut self, mode: GenerationMode)

Set the generation mode of the storage.

pub fn is_empty(&self) -> bool

Whether the strip storage is empty.

pub fn extend(&mut self, other: &Self)

Extend the current strip storage with the data from another storage.